@@ -107,6 +107,8 @@ from ml.fml40.features.properties.values.harvesting_parameter import HarvestingP
 from ml.fml40.features.properties.values.harvested_volume import HarvestedVolume
 from ml.fml40.features.properties.values.interfering_branches import InterferingBranches
 from ml.fml40.features.properties.values.inventory_data import InventoryData
+from ml.fml40.features.properties.values.maintenance_data import MaintenanceData
+from ml.fml40.features.properties.values.mean_height import MeanHeight
 from ml.fml40.features.properties.values.overhang import Overhang
 from ml.fml40.features.properties.values.stem_segment_properties import StemSegmentProperties
 from ml.fml40.features.properties.values.thickness_class import ThicknessClass
@@ -411,10 +413,9 @@ def create_thing(
 
 def _create_thing(model, grant_type="password",
                  secret="", username=None, password=None,
-                 is_broker_rest=False, is_broker=False, is_repo=False, is_stanford2010=False,
-                 is_stanford2010_sync=False,
-                 stanford2010_sync_freq=None, stanford2010_path=None, is_database=False,
-                 database_conf=None, database_file=None):
+                 is_broker_rest=False,
+                  is_broker=False,
+                  is_repo=False):
     """
     Creates and launches a thing which connects to the S3I
 
@@ -457,13 +458,7 @@ def _create_thing(model, grant_type="password",
         password=password,
         is_broker_rest=is_broker_rest,
         is_broker=is_broker,
-        is_repo=is_repo,
-        is_stanford2010=is_stanford2010,
-        stanford2010_sync_freq=stanford2010_sync_freq,
-        is_stanford2010_sync=is_stanford2010_sync,
-        stanford2010_path=stanford2010_path,
-        is_database=is_database,
-        database_file=database_file,
+        is_repo=is_repo
     )
     build(thing_ref, model)
 
