@@ -10,7 +10,7 @@ from s3i.repository import Repository
 from s3i.event_system import EventManager
 from ml.s3i_tools import Broker, BrokerREST
 from s3i.broker_message import GetValueReply, ServiceReply, SetValueReply, CustomEventReply, GetValueRequest, \
-    ServiceRequest, SetValueRequest
+    ServiceRequest, SetValueRequest, Message
 from s3i.exception import raise_error_from_s3ib_msg, S3IBMessageError, S3IDittoError, S3IIdentityProviderError
 from ml.app_logger import APP_LOGGER
 from ml.tools import find_broker_endpoint
@@ -39,7 +39,6 @@ class Thing:
             is_repository=False,
             is_broker=False,
             is_broker_rest=False,
-            is_event_manager=False,
             parameters=Parameters(),
             loop=asyncio.get_event_loop()
 
@@ -53,7 +52,6 @@ class Thing:
         self.__is_repository = is_repository
         self.__is_broker = is_broker
         self.__is_broker_rest = is_broker_rest
-        self.__is_event_manager = is_event_manager
         self.loop = loop
         self.__resGetValue = []
 
@@ -173,8 +171,7 @@ class Thing:
             self.__setup_repository()
         if self.__is_broker:
             self.__setup__broker()
-        if self.__is_event_manager:
-            self.__setup_event_system()
+        self.__setup_event_system()
 
     def __setup_identity_provider(self):
         APP_LOGGER.info("[S3I]: Connect to IdentityProvider")
@@ -280,14 +277,17 @@ class Thing:
         )
 
     def __setup_event_system(self):
+        APP_LOGGER.info("[S3I]: Setup event system")
         # TODO implement event system
         self.event_manager = EventManager(
             json_entry=self.entry.dt_json
         )
-        """
-        self.event_manager = EventManager(
-        )
-        """
+        events = self.entry.dir_json["attributes"].get("events")
+        if events is not None:
+            for key in events.keys():
+                self.event_manager.add_named_event(
+                    "{}.{}".format(self.identifier, key), events[key].get("schema")
+                )
 
     def __recursively_update_directory(self, frequency):
         try:
@@ -335,9 +335,16 @@ class Thing:
 
         """
         try:
-            body = literal_eval(body.decode('utf-8'))
+            decoded_body = body.decode('utf-8')
+            body = literal_eval(decoded_body)
+        except UnicodeDecodeError:
+            # Its a GZIP-based Byte message
+            body_obj = Message(gzip_msg=body)
+            body_obj.decompress(body_obj.gzip_msg)
+            body = body_obj.base_msg
         except ValueError:
             body = json.loads(body)
+
         # Add S3I-B Message validate
         try:
             body = raise_error_from_s3ib_msg(body, S3IBMessageError)
@@ -361,6 +368,12 @@ class Thing:
                 self.on_set_value_request(body)
             elif message_type == "eventSubscriptionRequest":
                 self.on_event_subscription_request(body)
+            elif message_type == "getValueReply":
+                self.on_get_value_reply(body)
+            elif message_type == "serviceReply":
+                self.on_service_reply(body)
+            elif message_type == "eventSubscriptionReply":
+                self.on_event_subscription_reply(body)
             else:
                 pass
 
@@ -763,6 +776,19 @@ class Thing:
         else:
             APP_LOGGER.error("[S3I]: Sending customEventReply failed")
 
+    def on_get_value_reply(self, msg):
+        pass
+
+    def on_service_reply(self, msg):
+        pass
+
+    def on_event_subscription_reply(self, msg):
+        pass
+
+    def on_set_value_reply(self, msg):
+        pass
+
+
     def verify_token(self):
         return jwt.decode(jwt=self.__token, verify=False)
 
